"""
RoboArt
~~~~~~~~~~~~~~~~~~~

A basic random avatar generator 

:copyright: (c) 2023 puang59
:license: MIT, see LICENSE for more details.

"""

__title__ = 'robotart'
__author__ = 'puang59'
__license__ = 'MIT'
__copyright__ = 'Copyright 2023 puang59'
__version__ = '0.0.1'

from .RoboArt import roboart



class roboart:
    def __init__(self): 
        self.base_url = "https://robohash.org"

    def robo(self, hash: str, set=1): 
        avatar = f"{self.base_url}/{hash}.png/?set=set{int(set)}"
        return avatar

    def monster(self, hash: str, set=2):
        avatar = f"{self.base_url}/{hash}.png/?set=set{int(set)}"
        return avatar
    
    def robohead(self, hash: str, set=3): 
        avatar = f"{self.base_url}/{hash}.png/?set=set{int(set)}"
        return avatar

    def kitten(self, hash: str, set=4): 
        avatar = f"{self.base_url}/{hash}.png/?set=set{int(set)}"
        return avatar




from setuptools import setup, find_packages

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

VERSION = '0.1.3'
DESCRIPTION = 'A basic random avatar generator'

# Setting up
setup(
    name="RoboArt",
    version=VERSION,
    author="puang59",
    author_email="puang59@proton.me",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'avatar', 'roboart', 'random avatar', 'robohash', 'robots art'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
